module MCP3021_Reader	(	
							Clk,		// System clock
							Rst_N,	// General reset active low
							SCL_in,	// I2C serial cloc input. Is this necessary for single master?
							SDA_in,	// I2C serial data input
							Conv,		// Start acquisition
							
							SCL_out,	// Serial clock output
							SDA_out,	// Serial data output
							SCL_oe,	// Output enable for SCL
							SDA_oe,	// Output enable for SDA
							ADC_rdy,	// ADC_rdy output - strobes high when data is available
							ADC_val	// 10 bit ADC register. ADC data is available in this register when ADC_Rdy
						);
			
input Clk;
input Rst_N;
input SCL_in;
input	SDA_in;
input Conv;

output	reg SCL_out;
output	reg SDA_out;
output	reg SCL_oe;
output	reg SDA_oe;
output	reg ADC_rdy;
output	reg [9:0] ADC_val;

reg[23:0] I2C_Period = 24'd0;				// I2C clock divider

parameter   CLK_IN_HZ =  16;    //25'd24000000;		// System clock frequency
parameter   I2C_SCL_HZ = 4;				// I2C SCL frequency (= 120 for 100KHz or 30 for 400KHz)
localparam  I2C_PERIOD_SIZE = (CLK_IN_HZ/I2C_SCL_HZ)-1 ;

always @ (posedge Clk) 
	begin
	if (!Rst_N) 
		begin
		I2C_Period <= I2C_PERIOD_SIZE ;
		ADC_rdy    <= 0;
		
		SCL_out    <= 1;  // I2C default state is all HIGH
		SCL_oe     <= 0;  // make I2C tristate by default.
		SDA_out    <= 1;  // I2C default state is all HIGH
		SDA_oe     <= 0;  // make I2C tristate by default.
		
		ADC_rdy    <= 0;
		end 
		
		else 
		begin
		if (I2C_Period == 0)
			begin
			
			SCL_out    <= 1;  // I2C default state is all HIGH
			SCL_oe     <= 1;  // make I2C tristate by default.
			SDA_out    <= 1;  // I2C default state is all HIGH
			SDA_oe     <= 1;  // make I2C tristate by default.
			
			ADC_rdy <= ~ADC_rdy;
			I2C_Period <= I2C_PERIOD_SIZE;
			end
			
			else
			begin
			I2C_Period <= I2C_Period - 1;
			end
		end

end // posedge clk

endmodule
